.. _install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Root Cause Analysis service, code-named vitrage, on the controller node.

This section assumes that you already have a working OpenStack
environment.

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 2

   install-rdo.rst
